bplustree

package module
v0.0.0-...-a286239 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2014 License: Apache-2.0 Imports: 1 Imported by: 0

README

bplustree

Documentation

Index

Constants

const (
	MaxKV = 255
	MaxKC = 511
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BTree

type BTree struct {
	// contains filtered or unexported fields
}

func (*BTree) First

func (bt *BTree) First() *leafNode

first returns the first leafNode

func (*BTree) Insert

func (bt *BTree) Insert(key int, value string)

insert inserts a (key, value) into the B+ tree

func (*BTree) Search

func (bt *BTree) Search(key int) (string, bool)

Search searches the key in B+ tree If the key exists, it returns the value of key and true If the key does not exist, it returns an empty string and false

Jump to