Discover Packages
github.com/MrRightLi/bplustree
package
module
Version:
v0.0.0-...-a286239
Opens a new window with list of versions in this module.
Published: Apr 21, 2014
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
README
¶
Expand ▾
Collapse ▴
Documentation
¶
func (bt *BTree ) First() *leafNode
first returns the first leafNode
insert inserts a (key, value) into the B+ tree
Search searches the key in B+ tree
If the key exists, it returns the value of key and true
If the key does not exist, it returns an empty string and false
Source Files
¶
Click to show internal directories.
Click to hide internal directories.